summaryrefslogtreecommitdiffstats
path: root/net/spdy/spdy_session_pool.h
diff options
context:
space:
mode:
Diffstat (limited to 'net/spdy/spdy_session_pool.h')
-rw-r--r--net/spdy/spdy_session_pool.h7
1 files changed, 4 insertions, 3 deletions
diff --git a/net/spdy/spdy_session_pool.h b/net/spdy/spdy_session_pool.h
index 7efb400..149deb0 100644
--- a/net/spdy/spdy_session_pool.h
+++ b/net/spdy/spdy_session_pool.h
@@ -18,11 +18,12 @@
#include "net/base/net_errors.h"
#include "net/base/network_change_notifier.h"
#include "net/proxy/proxy_config.h"
+#include "net/proxy/proxy_server.h"
namespace net {
-// Sessions are uniquely identified by their HostPortPair and the PAC-style list
-// of valid proxy servers.
-typedef std::pair<HostPortPair, std::string> HostPortProxyPair;
+// Sessions are uniquely identified by their HostPortPair and the proxy server
+// that will be used to connect to it (may be DIRECT).
+typedef std::pair<HostPortPair, ProxyServer> HostPortProxyPair;
class BoundNetLog;
class ClientSocketHandle;